{
  config,
  inputs,
  ...
}: {
  imports = with inputs; [
    self.nixosModules.config
    self.nixosModules.desktop
    self.nixosModules.system
    ./disko
    ./minecraft.nix
  ];

  networking = {
    networkmanager.enable = true;
    hostId = "c7f6c4a1";
    hostName = "dunamis";
  };

  environment.memoryAllocator.provider = "mimalloc";
  system.stateVersion = "25.05";
  time.timeZone = "Europe/Kyiv";

  desktop.niri.enable = true;

  module = {
    config = {
      secureBoot = true;
      tpmDiskUnlock = true;
      vaapi = "intel-media-driver";
    };
    stylix = {
      enable = true;
      theme = "helios";
    };
  };

  locale.ukrainian.enable = true;
  opentabletdriver.enable = false;
  qmk-vial.enable = true;
  virtual.libvirt.enable = true;

  nix = let
    inherit (builtins) readFile;
    inherit (config.users.users) user;
  in {
    settings.trusted-users = ["nix-ssh"];
    sshServe = {
      enable = true;
      write = true;
      keys = map (f: readFile f) user.openssh.authorizedKeys.keyFiles;
    };
  };
}
