{inputs, ...}: let
  disk = "/dev/disk/by-id/nvme-INTEL_SSDPEKKF256G8L_BTHH81460QC2256B";
  disk1 = "/dev/disk/by-id/nvme-WDC_PC_SN730_SDBPNTY-1T00-1101_21114D802446";
in {
  imports = with inputs; [
    disko.nixosModules.disko
  ];
  disko.devices.nodev = {
    "/tmp" = {
      fsType = "tmpfs";
      mountOptions = ["rw" "nosuid" "nodev"];
    };
  };
  disko.devices.disk.main = {
    type = "disk";
    device = disk;
    content = {
      type = "gpt";
      partitions = {
        ESP = {
          size = "2G";
          type = "EF00";
          content = {
            type = "filesystem";
            format = "vfat";
            mountpoint = "/boot";
            mountOptions = [
              "umask=0077"
              "fmask=0022"
              "dmask=0022"
              "noexec"
              "nosuid"
              "nodev"
            ];
          };
        };
        luks = {
          size = "100%";
          content = {
            type = "luks";
            name = "luks-main";
            initrdUnlock = true;
            settings.allowDiscards = true;
            content = {
              type = "btrfs";
              extraArgs = ["-f"];
              subvolumes = {
                "@root-nixos" = {
                  mountpoint = "/";
                  mountOptions = [
                    "compress=zstd"
                    "noatime"
                    # "noexec"
                  ];
                };
                "@home" = {
                  mountpoint = "/home";
                  mountOptions = [
                    "compress=zstd"
                    "noatime"
                  ];
                };
                "@swap" = {
                  mountpoint = "/swap";
                  mountOptions = [
                    # "compress=zstd"
                    "noatime"
                  ];
                };
                # "@nix" = {
                #   mountpoint = "/nix";
                #   mountOptions = [
                #     "compress-force=zstd"
                #     "noatime"
                #   ];
                # };
              };
            };
          };
        };
      };
    };
  };
  disko.devices.disk.second = {
    type = "disk";
    device = disk1;
    content = {
      type = "gpt";
      partitions = {
        luks = {
          size = "100%";
          content = {
            type = "luks";
            name = "luks-second";
            initrdUnlock = true;
            settings.allowDiscards = true;
            content = {
              type = "btrfs";
              extraArgs = ["-f"];
              subvolumes = {
                "@storage" = {
                  mountpoint = "/storage";
                  mountOptions = [
                    "compress=zstd"
                    "noatime"
                  ];
                };
              };
            };
          };
        };
      };
    };
  };
}
