{
  getExe,
  perSystem,
  pkgs,
  lockscreen,
  ...
}: {
  copyq.enable = true;
  copyq.package = perSystem.nixpkgs-stable.copyq;
  network-manager-applet.enable = true;
  playerctld.enable = true;
  swayosd = {
    enable = true;
    topMargin = 0.8;
  };
  wpaperd.enable = true;
  gnome-keyring = {
    enable = true;
    components = ["secrets"];
  };
  gammastep = {
    enable = true;
    provider = "manual";
    latitude = 49.6;
    longitude = 36.1;
    tray = true;
    temperature = {
      day = 6500;
      night = 3000;
    };
  };
  udiskie = {
    enable = true;
    automount = false;
    notify = true;
    tray = "auto";
  };
  swaync = {
    enable = true;
    settings = {
      cssPriority = "user";
      image-visibility = "when-available";
      keyboard-shortcut = true;
      relative-timestamps = true;
      timeout = 5;
      timeout-low = 5;
      timeout-critical = 0;
      script-fail-notify = true;
      transition-time = 200;

      # Layer settings
      layer-shell = true;
      layer = "overlay";
      control-center-layer = "overlay";

      # Notification settings
      positionX = "right";
      positionY = "top";
      notification-2fa-action = true;
      notification-inline-replies = false;
      notification-icon-size = 32;
      notification-body-image-height = 100;
      notification-body-image-width = 200;
      notification-window-width = 400;

      # Control center settings
      control-center-positionX = "right";
      control-center-positionY = "top";
      control-center-width = 500;
      control-center-exclusive-zone = true;
      fit-to-screen = true;
      hide-on-action = true;
      hide-on-clear = false;

      # Widget settings
      widgets = [
        "title"
        "dnd"
        "notifications"
        "mpris"
      ];

      widget-config = {
        title = {
          text = "Notifications";
          clear-all-button = true;
          button-text = "Clear All";
        };
        dnd = {
          text = "Do Not Disturb";
        };
        mpris = {
          image-size = 96;
          image-radius = 12;
          blur = true;
        };
      };
    };
    style = ''
      /*** Global ***/
      progress,
      progressbar,
      trough {
        border-radius: 16px;
      }

      .app-icon,
      .image {
        -gtk-icon-effect: none;
      }

      .notification-action {
        border-radius: 12px;
        margin: 0.5rem;
      }

      .close-button {
        margin: 24px;
        padding: 0.2rem;
        border-radius: 16px;
      }

      /*** Notifications ***/
      .notification-group.collapsed
        .notification-row:not(:last-child)
        .notification-action,
      .notification-group.collapsed
        .notification-row:not(:last-child)
        .notification-default-action {
        opacity: 0;
      }

      .trough {
        margin: 4px;
        border-radius: 7px;
      }

      .notification,
      .notification.low,
      .notification.normal,
      .notification.critical,
      .control-center {
        margin: 16px;
        border-radius: 7px;
      }

      .floating-notifications,
      .notification-content {
        border-radius: 7px;
      }

      .control-center-list {
        background: transparent;
      }

      /*** Widgets ***/
      /* Title widget */
      .widget-title {
        margin: 0.5rem;
      }

      .widget-title > label {
        font-weight: bold;
      }

      .widget-title > button {
        border-radius: 16px;
        padding: 0.5rem;
      }

      /* DND Widget */
      .widget-dnd {
        margin: 0.5rem;
      }

      .widget-dnd > label {
        font-weight: bold;
      }

      .widget-dnd > switch {
        border-radius: 16px;
      }

      .widget-dnd > switch slider {
        border-radius: 16px;
        padding: 0.25rem;
      }

      /* Mpris widget */
      .widget-mpris .widget-mpris-player {
        border-radius: 16px;
        margin: 0.5rem;
        padding: 0.5rem;
      }

      .widget-mpris .widget-mpris-player .widget-mpris-album-art {
        border-radius: 16px;
      }

      .widget-mpris .widget-mpris-player .widget-mpris-title {
        font-weight: bold;
      }

      .widget-mpris .widget-mpris-player .widget-mpris-subtitle {
        font-weight: normal;
      }

      .widget-mpris .widget-mpris-player > box > button {
        border: 1px solid transparent;
        border-radius: 16px;
        padding: 0.25rem;
      }
    '';
  };
  hypridle = {
    enable = true;
    settings = {
      general = {
        before_sleep_cmd = "loginctl lock-session";
        lock_cmd = "pidof ${lockscreen} || ${lockscreen}";
        # unlock_cmd = "loginctl unlock-session";
      };
      listener = [
        {
          timeout = 600;
          on-timeout = "pidof ${lockscreen} || ${lockscreen}";
        }
        {
          timeout = 601;
          on-timeout = getExe pkgs.niri + " msg action power-off-monitors";
        }
      ];
    };
  };
}
